@@ -106,7 +106,7 @@ def fake_client():
 
 
 class FakeClient:
-    def find_device(self, *args, name, **kwargs):
+    def find_item(self, *args, name, **kwargs):
         return HappiItem(
             name=name,
             device_class='typhos.tests.test_alarm.SimpleDevice',
@@ -117,7 +117,7 @@ class FakeClient:
 @pytest.mark.parametrize("metadata,response", alarm_cases)
 def test_one_alarm_happi_ch(alarm, qtbot, metadata, response, fake_client):
     name = 'happi_test_device_' + str(uuid4()).replace('-', '_')
-    item = fake_client.find_device(name=name)
+    item = fake_client.find_item(name=name)
     device = from_container(item)
 
     with qtbot.wait_signal(alarm.alarm_changed, timeout=1000):
