@@ -54,6 +54,8 @@ DEBUG_MODE = bool(os.environ.get('TYPHOS_DEBUG', False))
 # Help settings:
 # TYPHOS_HELP_URL (str): The help URL format string
 HELP_URL = os.environ.get('TYPHOS_HELP_URL', "").strip()
+HELP_WEB_ENABLED = bool(HELP_URL.strip())
+
 # TYPHOS_HELP_HEADERS (json): headers to pass to HELP_URL
 HELP_HEADERS = json.loads(os.environ.get('TYPHOS_HELP_HEADERS', "") or "{}")
 HELP_HEADERS_HOSTS = os.environ.get("TYPHOS_HELP_HEADERS_HOSTS", "").split(",")
@@ -741,7 +743,7 @@ def code_from_device(device):
 import happi
 from happi.loader import from_container
 client = happi.Client.from_config()
-md = client.find_device(name="{happi_name}")
+md = client.find_item(name="{happi_name}")
 {device.name} = from_container(md)
 '''
 
